@@ -1,15 +1,13 @@
 use strict; use warnings;
 package YAMLScript::Core;
 
-use Lingy::Common;
+use YAMLScript::Common;
 
 sub ends_with_q {
     my ($str, $substr) = @_;
-    $str = $$str;
-    $substr = $$substr;
     BOOLEAN->new(
-      length($str) >= length($substr) and
-      substr($str, 0-length($substr)) eq $substr
+      length("$str") >= length("$substr") and
+      substr("$str", 0-length("$substr")) eq "$substr"
     );
 }
 
